==> ec2-0.33.0-sources.jar: software/amazon/awscdk/services/ec2/PrefixList.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A prefix list.
 * 
 * Prefix lists are used to allow traffic to VPC-local service endpoints.
 * 
 * For more information, see this page:
 * 
 * https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-endpoints.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.0 (build 3d6415e)", date = "2019-05-30T15:03:30.399Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.PrefixList")
public class PrefixList extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.ISecurityGroupRule,software.amazon.awscdk.services.ec2.IConnectable {
    protected PrefixList(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public PrefixList(final java.lang.String prefixListId) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(prefixListId, "prefixListId is required") });
    }

    /**
     * Produce the egress rule JSON for the given connection.
     */
    @Override
    @javax.annotation.Nullable
    public java.lang.Object toEgressRuleJSON() {
        return this.jsiiCall("toEgressRuleJSON", java.lang.Object.class);
    }

    /**
     * Produce the ingress rule JSON for the given connection.
     */
    @Override
    @javax.annotation.Nullable
    public java.lang.Object toIngressRuleJSON() {
        return this.jsiiCall("toIngressRuleJSON", java.lang.Object.class);
    }

    /**
     * Whether the rule can be inlined into a SecurityGroup or not.
     */
    @Override
    public java.lang.Boolean getCanInlineRule() {
        return this.jsiiGet("canInlineRule", java.lang.Boolean.class);
    }

    @Override
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    public java.lang.String getPrefixListId() {
        return this.jsiiGet("prefixListId", java.lang.String.class);
    }

    /**
     * A unique identifier for this connection peer.
     */
    @Override
    public java.lang.String getUniqueId() {
        return this.jsiiGet("uniqueId", java.lang.String.class);
    }
}

==> ec2-0.34.0-sources.jar: software/amazon/awscdk/services/ec2/PrefixList.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A prefix list.
 * 
 * Prefix lists are used to allow traffic to VPC-local service endpoints.
 * 
 * For more information, see this page:
 * 
 * https://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/vpc-endpoints.html
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:04:59.492Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.PrefixList")
public class PrefixList extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.ISecurityGroupRule,software.amazon.awscdk.services.ec2.IConnectable {
    protected PrefixList(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PrefixList(final java.lang.String prefixListId) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(prefixListId, "prefixListId is required") });
    }

    /**
     * Produce the egress rule JSON for the given connection.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    @javax.annotation.Nullable
    public java.lang.Object toEgressRuleJSON() {
        return this.jsiiCall("toEgressRuleJSON", java.lang.Object.class);
    }

    /**
     * Produce the ingress rule JSON for the given connection.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    @javax.annotation.Nullable
    public java.lang.Object toIngressRuleJSON() {
        return this.jsiiCall("toIngressRuleJSON", java.lang.Object.class);
    }

    /**
     * Whether the rule can be inlined into a SecurityGroup or not.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.Boolean getCanInlineRule() {
        return this.jsiiGet("canInlineRule", java.lang.Boolean.class);
    }

    /**
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getPrefixListId() {
        return this.jsiiGet("prefixListId", java.lang.String.class);
    }

    /**
     * A unique identifier for this connection peer.
     * 
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getUniqueId() {
        return this.jsiiGet("uniqueId", java.lang.String.class);
    }
}
